pub unsafe fn fence_i()ðŽThis is a nightly-only experimental API. (
riscv_ext_intrinsics #114544)Available on (RISC-V RV32 or RISC-V RV64) and (RISC-V RV64) only.
Generates the FENCE.I instruction
A FENCE.I instruction ensures that a subsequent instruction fetch on a RISC-V hart will see any previous data stores already visible to the same RISC-V hart.
FENCE.I does not ensure that other RISC-V hartsâ instruction fetches will observe the local hartâs stores in a multiprocessor system.